==> baseZhang-1.4.0.tar.gz: baseZhang-1.4.0/baseZhang/__init__.py <==
from .baseZhang import reduceListFilter, align_two_list_with_same_len, del_the_file, if_no_create_it, init_data_dir, \
    print_to_check, \
    savefig, update_pip_install_packages, wavread, wavwrite, normalize_data, read_mat_data, save_mat_data
from .calcChroma import calcChroma_cens, calcChroma_cqt, calcChroma_stft, calcTonnetz
from .calcLPCC import calcLPCC
from .calcMFCC import calcMFCC, calcMFCC_delta, calcMFCC_delta_delta, fbank, log_fbank, log_spectrum_power
from .calcSpec import get_spec, get_spec_2, get_spec_gammatone, plot_spec_gammatone, plot_spectrogram
from .calcSpectralFeatureLibrosa import calc_poly_features, calc_rmse, calc_spectral_bandwidth, calc_spectral_centroid, \
    calc_spectral_contrast, calc_spectral_rolloff, calc_zero_crossing_rate
from .callMatlabFunction import run_matlab_codes
from .countDays import countDaysBettweenTwo
from .datasetPreprocess import class_encoder_to_number, class_number_encode_to_one_hot_code, \
    one_hot_code_to_class_number_encode, number_to_class_name, split_dataset_to_tain_test, load_train_test_data
from .featureSelect import removeLowVarianceFeatures, selectKbestFeature
from .formatTrans import mp32Wav, mpeg2wav, wav2MFCC, video2mp4
from .kerasModel import load_model, load_model_weights, save_model, save_model_weights
from .labeEncodeDecode import decode, encode
from .modifyMarkdown import modify_markdown
from .plotVisualData import plot_waveform, plotDuralWav, plotmono_waveform, plotstereo_waveform, plotstft, plotMonoWav, \
    plotssd, plotmatrix
from .recordAudio import recordAudio
from .split2word import split_into_words
from .videoProcess import videoProcess
from .youtubePdfDown import download_youtube, download_youtube_playlist, pdf_link_2_txt

==> baseZhang-1.4.2.tar.gz: baseZhang-1.4.2/baseZhang/__init__.py <==
from .baseZhang import reduceListFilter, align_two_list_with_same_len, del_the_file, if_no_create_it, init_data_dir, \
    print_to_check, \
    savefig, update_pip_install_packages, wavread, wavwrite, normalize_data, read_mat_data, save_mat_data
from .calcAudioFeature import get_audio_feature, substractFeat
from .calcChroma import calcChroma_cens, calcChroma_cqt, calcChroma_stft, calcTonnetz
from .calcLPCC import calcLPCC
from .calcMFCC import calcMFCC, calcMFCC_delta, calcMFCC_delta_delta, fbank, log_fbank, log_spectrum_power
from .calcSpec import get_spec, get_spec_2, get_spec_gammatone, plot_spec_gammatone, plot_spectrogram
from .calcSpectralFeatureLibrosa import calc_poly_features, calc_rmse, calc_spectral_bandwidth, calc_spectral_centroid, \
    calc_spectral_contrast, calc_spectral_rolloff, calc_zero_crossing_rate
from .callMatlabFunction import run_matlab_codes
from .countDays import countDaysBettweenTwo
from .datasetPreprocess import class_encoder_to_number, class_number_encode_to_one_hot_code, \
    one_hot_code_to_class_number_encode, number_to_class_name, split_dataset_to_tain_test, load_train_test_data
from .downYoutubeGUI import downVideoGUI
from .downYoutubeGUI import down_link_txt
from .downYoutubeGUI import download_youtube, download_youtube_playlist, pdf_link_2_txt
from .downYoutubeGUI import videoProcess
from .featureSelect import removeLowVarianceFeatures, selectKbestFeature
from .formatTrans import mp32Wav, mpeg2wav, wav2MFCC, video2mp4
from .kerasModel import load_model, load_model_weights, save_model, save_model_weights
from .labeEncodeDecode import decode, encode
from .modifyMarkdown import modify_markdown
from .plotVisualData import plot_waveform, plotDuralWav, plotmono_waveform, plotstereo_waveform, plotstft, plotMonoWav, \
    plotssd, plotmatrix
from .recordAudio import recordAudio
from .split2word import split_into_words
